@@ -1,25 +1,40 @@
 # -*- coding: utf-8 -*-
-"""The readline based xonsh shell."""
+"""The readline based xonsh shell.
+
+Portions of this code related to initializing the readline library
+are included from the IPython project.  The IPython project is:
+
+* Copyright (c) 2008-2014, IPython Development Team
+* Copyright (c) 2001-2007, Fernando Perez <fernando.perez@colorado.edu>
+* Copyright (c) 2001, Janko Hauser <jhauser@zscout.de>
+* Copyright (c) 2001, Nathaniel Gray <n8gray@caltech.edu>
+
+"""
 import os
 import sys
 import time
 import select
 import builtins
+import importlib
 from cmd import Cmd
 from threading import Thread
 from collections import deque
 
-from xonsh import lazyjson
+from xonsh.lazyjson import LazyJSON
+from xonsh.lazyasd import LazyObject
 from xonsh.base_shell import BaseShell
 from xonsh.ansi_colors import partial_color_format, color_style_names, color_style
 from xonsh.environ import partial_format_prompt, multiline_prompt
 from xonsh.tools import print_exception
-from xonsh.platform import HAS_PYGMENTS, ON_WINDOWS, ON_CYGWIN
+from xonsh.platform import HAS_PYGMENTS, ON_WINDOWS, ON_CYGWIN, ON_DARWIN
 
-if HAS_PYGMENTS:
-    from xonsh import pyghooks
-    import pygments
-    from pygments.formatters.terminal256 import Terminal256Formatter
+pygments = LazyObject(lambda: importlib.import_module('pygments'),
+                      globals(), 'pygments')
+terminal256 = LazyObject(lambda: importlib.import_module(
+                                    'pygments.formatters.terminal256'),
+                      globals(), 'terminal')
+pyghooks = LazyObject(lambda: importlib.import_module('xonsh.pyghooks'),
+                      globals(), 'pyghooks')
 
 readline = None
 RL_COMPLETION_SUPPRESS_APPEND = RL_LIB = RL_STATE = None
@@ -34,12 +49,20 @@ def setup_readline():
     global RL_COMPLETION_SUPPRESS_APPEND, RL_LIB, RL_CAN_RESIZE, RL_STATE, readline
     if RL_COMPLETION_SUPPRESS_APPEND is not None:
         return
-    try:
-        import readline
-    except ImportError:
+    for _rlmod_name in ('gnureadline', 'readline'):
+        try:
+            readline = importlib.import_module(_rlmod_name)
+            sys.modules['readline'] = readline
+        except ImportError:
+            pass
+        else:
+            break
+    if readline is None:
+        print("No readline implementation available.  Skipping setup.")
         return
     import ctypes
     import ctypes.util
+    uses_libedit = readline.__doc__ and 'libedit' in readline.__doc__
     readline.set_completer_delims(' \t\n')
     # Cygwin seems to hang indefinitely when querying the readline lib
     if (not ON_CYGWIN) and (not readline.__file__.endswith('.py')):
@@ -67,16 +90,36 @@ def setup_readline():
 
     # handle tab completion differences found in libedit readline compatibility
     # as discussed at http://stackoverflow.com/a/7116997
-    if readline.__doc__ and 'libedit' in readline.__doc__:
+    if uses_libedit and ON_DARWIN:
         readline.parse_and_bind("bind ^I rl_complete")
+        print('\n'.join(['', "*"*78,
+            "libedit detected - readline will not be well behaved, including but not limited to:",
+            "   * crashes on tab completion",
+            "   * incorrect history navigation",
+            "   * corrupting long-lines",
+            "   * failure to wrap or indent lines properly",
+            "",
+            "It is highly recommended that you install gnureadline, which is installable with:",
+            "     pip install gnureadline",
+            "*"*78]), file=sys.stderr)
     else:
         readline.parse_and_bind("tab: complete")
     # try to load custom user settings
-    try:
-        readline.read_init_file()
-    except Exception:
-        # this seems to fail with libedit
-        print_exception('xonsh: could not load readline default init file.')
+    inputrc_name = os.environ.get('INPUTRC')
+    if inputrc_name is None:
+        if uses_libedit:
+            inputrc_name = '.editrc'
+        else:
+            inputrc_name = '.inputrc'
+        inputrc_name = os.path.join(os.path.expanduser('~'), inputrc_name)
+    if (not ON_WINDOWS) and (not os.path.isfile(inputrc_name)):
+        inputrc_name = '/etc/inputrc'
+    if os.path.isfile(inputrc_name):
+        try:
+            readline.read_init_file(inputrc_name)
+        except Exception:
+            # this seems to fail with libedit
+            print_exception('xonsh: could not load readline default init file.')
 
 
 def teardown_readline():
@@ -194,10 +237,13 @@ class ReadlineShell(BaseShell, Cmd):
         rl_completion_suppress_append()  # this needs to be called each time
         mline = line.partition(' ')[2]
         offs = len(mline) - len(text)
-        x = [(i[offs:] if " " in i[:-1] else i)
-             for i in self.completer.complete(text, line,
-                                              begidx, endidx,
-                                              ctx=self.ctx)[0]]
+        if self.completer is None:
+            x = []
+        else:
+            x = [(i[offs:] if " " in i[:-1] else i)
+                 for i in self.completer.complete(text, line,
+                                                  begidx, endidx,
+                                                  ctx=self.ctx)[0]]
         return x
 
     # tab complete on first index too
@@ -375,7 +421,7 @@ class ReadlineShell(BaseShell, Cmd):
             env = builtins.__xonsh_env__
             self.styler.style_name = env.get('XONSH_COLOR_STYLE')
             style_proxy = pyghooks.xonsh_style_proxy(self.styler)
-            formatter = Terminal256Formatter(style=style_proxy)
+            formatter = terminal256.Terminal256Formatter(style=style_proxy)
             s = pygments.format(string, formatter).rstrip()
         print(s, **kwargs)
 
@@ -412,7 +458,7 @@ class ReadlineHistoryAdder(Thread):
         i = 1
         for _, _, f in files:
             try:
-                lj = lazyjson.LazyJSON(f, reopen=False)
+                lj = LazyJSON(f, reopen=False)
                 for cmd in lj['cmds']:
                     inp = cmd['inp'].splitlines()
                     for line in inp:
@@ -423,5 +469,5 @@ class ReadlineHistoryAdder(Thread):
                             RL_LIB.history_set_pos(i)
                         i += 1
                 lj.close()
-            except (IOError, OSError):
+            except (IOError, OSError, ValueError):
                 continue
